package com.menagerie.ophelia

import android.os.Bundle
import androidx.activity.ComponentActivity
import androidx.activity.compose.setContent
import androidx.compose.foundation.Image
import androidx.compose.foundation.layout.Arrangement
import androidx.compose.foundation.layout.Box
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.padding
import androidx.compose.material3.Surface
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.layout.ContentScale
import androidx.compose.ui.res.painterResource
import androidx.compose.ui.res.stringResource
import androidx.compose.ui.text.style.TextAlign
import androidx.compose.ui.tooling.preview.Preview
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import com.menagerie.ophelia.ui.theme.OpheliaTheme

class MainActivity : ComponentActivity() {
    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        setContent {
            OpheliaTheme {
                // A surface container using the 'background' color from the theme
                Surface(
                    modifier = Modifier.fillMaxSize(),
                    color = Color.White
                ) {
//                    GreetingImage(
//                        message = getString(R.string.main_welcome_message),
//                        from = getString(R.string.tagline)
//                    )

                    EventDemo()
                }
            }
        }
    }
}

//storing multiple events
val events = mutableListOf<Event>(
    Event(
        title ="",
        daypart = DayPart.EVENING,
        duration = 40
    ),
    Event(
        title ="",
        daypart = DayPart.MORNING,
        duration = 40
    ),
    Event(
        title ="",
        daypart = DayPart.EVENING,
        duration = 40
    ),
    Event(
        title ="",
        daypart = DayPart.AFTERNOON,
        duration = 40
    ),
    Event(
        title ="",
        daypart = DayPart.EVENING,
        duration = 40
    ),
    Event(
        title ="",
        daypart = DayPart.AFTERNOON,
        duration = 40
    ),
    Event(
        title ="",
        daypart = DayPart.EVENING,
        duration = 40
    ),
)

val shortEvents = events.filter{
    it.duration < 60
}


enum class DayPart{
    MORNING,
    AFTERNOON,
    EVENING,
}
data class Event(
    val title: String,
    val description: String? = null,
    val daypart: DayPart,
    val duration: Int
)

@Composable
fun EventDemo() {

    Column {
        events.groupBy { it.daypart }.forEach{(daypart, events)->
            Text(text = "$daypart: ${events.size} Events")
        }
    }
    
}

@Composable
fun GreetingImage(message: String, from: String, modifier: Modifier = Modifier) {
    val image = painterResource(R.drawable.androidparty)
    Box {
        Image(
            painter = image,
            contentDescription = null,
            contentScale = ContentScale.Crop,
            alpha = 0.5F,
        )
        GreetingText(
            message = message,
            from = from,
            modifier = Modifier
                .fillMaxSize()
                .padding(8.dp)
        )
    }
}

@Composable
fun GreetingText(message: String, from: String, modifier: Modifier = Modifier) {
    // Create a column so that texts don't overlap
    Column(
        verticalArrangement = Arrangement.Center,
        modifier = modifier
    ) {
        Text(
            text = message,
            color = Color.Black,
            fontSize = 70.sp,
            lineHeight = 116.sp,
            textAlign = TextAlign.Center
        )
        Text(
            text = from,
            color = Color.Black,
            fontSize = 36.sp,
            modifier = Modifier
                .padding(16.dp)
                .align(alignment = Alignment.CenterHorizontally)
        )
    }
}

@Preview(showBackground = true)
@Composable
fun BirthdayCardPreview() {
    OpheliaTheme {
//        GreetingImage(
//            message = stringResource(R.string.main_welcome_message),
//            from = stringResource(R.string.tagline)
//        )
        EventDemo()
    }
}
